@@ -25,7 +25,7 @@
 #define IO_DEBUG 0
 
 static inline void display_help(char *str){
-  fprintf(stdout, "\nmsolve library for polynomial system solving\n");
+  fprintf(stdout, "\nmsolve library for polynomial system solving, version %s\n", VERSION);
   fprintf(stdout, "implemented by J. Berthomieu, C. Eder, M. Safey El Din\n");
   fprintf(stdout, "\n");
   /* fprintf(stdout, "commit hash: %s\n\n", GIT_COMMIT_HASH); */
@@ -121,6 +121,10 @@ static inline void display_help(char *str){
   fprintf(stdout, "         Default is 0. For a detailed description of the output\n");
   fprintf(stdout, "         format please see the general output data format section\n");
   fprintf(stdout, "         above.\n");
+  fprintf(stdout, "-L LIF   Controls lifting of multplication matrices over the rationals.\n");
+  fprintf(stdout, "         Default is 0 (no lifting). \n");
+  fprintf(stdout, "         Matrices are lifted when LIF is 1.\n");
+  fprintf(stdout, "         Warning: when activated, this option may cause higher memory consumption.\n");
   fprintf(stdout, "-q Q     Uses signature-based algorithms.\n");
   fprintf(stdout, "         Default: 0 (no).\n");
   fprintf(stdout, "-r RED   Reduce Groebner basis.\n");
@@ -137,6 +141,7 @@ static inline void display_help(char *str){
   fprintf(stdout, "-u UHT   Number of steps after which the\n");
   fprintf(stdout, "         hash table is newly generated.\n");
   fprintf(stdout, "         Default: 0, i.e. no update.\n");
+  fprintf(stdout, "-V       Prints msolve's version\n");
 }
 
 static void getoptions(
@@ -159,6 +164,7 @@ static void getoptions(
         int32_t *normal_form,
         int32_t *normal_form_matrix,
         int32_t *is_gb,
+        int32_t *lift_matrix,
         int32_t *get_param,
         int32_t *precision,
         int32_t *refine,
@@ -172,7 +178,7 @@ static void getoptions(
   char *out_fname = NULL;
   char *bin_out_fname = NULL;
   opterr = 1;
-  char options[] = "hf:N:F:v:l:t:e:o:O:u:iI:p:P:q:g:c:s:SCr:R:m:M:n:d:";
+  char options[] = "hf:N:F:v:l:t:e:o:O:u:iI:p:P:L:q:g:c:s:SCr:R:m:M:n:d:Vf:";
   while((opt = getopt(argc, argv, options)) != -1) {
     switch(opt) {
     case 'N':
@@ -181,6 +187,9 @@ static void getoptions(
     case 'h':
       display_help(argv[0]);
       exit(0);
+    case 'V':
+      fprintf(stdout, "%s\n", VERSION);
+      exit(0);
     case 'e':
       *elim_block_len = strtol(optarg, NULL, 10);
       if (*elim_block_len < 0) {
@@ -235,6 +244,9 @@ static void getoptions(
     case 'v':
       *info_level = strtol(optarg, NULL, 10);
       break;
+    case 'L':
+      *lift_matrix= strtol(optarg, NULL, 10);
+      break;
     case 't':
       *nthreads = strtol(optarg, NULL, 10);
       break;
@@ -353,6 +365,7 @@ int main(int argc, char **argv){
     int32_t normal_form           = 0;
     int32_t normal_form_matrix    = 0;
     int32_t is_gb                 = 0;
+    int32_t lift_matrix           = 0;
     int32_t get_param             = 0;
     int32_t precision             = 128;
     int32_t refine                = 0; /* not used at the moment */
@@ -367,7 +380,7 @@ int main(int argc, char **argv){
     getoptions(argc, argv, &initial_hts, &nr_threads, &max_pairs,
                &elim_block_len, &la_option, &use_signatures, &update_ht,
                &reduce_gb, &print_gb, &truncate_lifting, &genericity_handling, &unstable_staircase, &saturate, &colon,
-               &normal_form, &normal_form_matrix, &is_gb, &get_param,
+               &normal_form, &normal_form_matrix, &is_gb, &lift_matrix, &get_param,
                &precision, &refine, &isolate, &generate_pbm, &info_level, files);
 
     FILE *fh  = fopen(files->in_file, "r");
@@ -413,10 +426,12 @@ int main(int argc, char **argv){
     gens->random_linear_form = malloc(sizeof(int32_t)*(nr_vars));
     gens->elim = elim_block_len;
 
-    if(0 < field_char && field_char < pow(2, 15) && la_option > 2 && info_level){
-      fprintf(stderr, "Warning: characteristic is too low for choosing \nprobabilistic linear algebra\n");
-      fprintf(stderr, "\t linear algebra option set to 2\n");
-      la_option = 2;
+    if(0 < field_char && field_char < pow(2, 15) && la_option > 2){
+        if(info_level){
+            fprintf(stderr, "Warning: characteristic is too low for choosing \nprobabilistic linear algebra\n");
+            fprintf(stderr, "\t linear algebra option set to 2\n");
+        }
+        la_option = 2;
     }
     
     /* data structures for parametrization */
@@ -433,7 +448,7 @@ int main(int argc, char **argv){
                           initial_hts, max_pairs, elim_block_len, update_ht,
                           generate_pbm, reduce_gb, print_gb, truncate_lifting, get_param,
                           genericity_handling, unstable_staircase, saturate, colon, normal_form,
-                          normal_form_matrix, is_gb, precision, 
+                          normal_form_matrix, is_gb, lift_matrix, precision, 
                           files, gens,
             &param, mpz_paramp, &nb_real_roots, &real_roots, &real_pts);
 
